@@ -1,45 +1,53 @@
 use std::collections::HashMap;
-use std::hash::Hash;
 use std::collections::HashSet;
 use std::fmt;
+use std::hash::Hash;
 
 #[derive(Debug, Clone, PartialEq)]
 pub struct UnionFind<N: Copy + Hash + Eq + Clone> {
     _size: usize,
     pub parents: HashMap<N, N>,
-    rank: HashMap<N, usize>
+    rank: HashMap<N, usize>,
 }
 
-
 pub trait UnionFindTrait<N: Copy + Eq + Hash + Clone> {
     fn find(&mut self, node: N) -> N;
     fn union(&mut self, x: N, y: N);
-    fn into_subsets(&mut self) -> Vec<HashSet<N>>;
+    fn subsets(&mut self) -> Vec<HashSet<N>>;
 }
 
+impl<T> Default for UnionFind<T>
+where
+    T: Copy + Eq + Hash + Clone,
+{
+    fn default() -> Self {
+        Self::new()
+    }
+}
 
 impl<T> UnionFind<T>
-    where T: Copy + Eq + Hash + Clone
+where
+    T: Copy + Eq + Hash + Clone,
 {
     pub fn new() -> UnionFind<T> {
         let parents: HashMap<T, T> = HashMap::new();
         let rank: HashMap<T, usize> = HashMap::new();
-        // for 
+        // for
         UnionFind {
             _size: 0,
             parents,
-            rank
+            rank,
         }
     }
 
     pub fn with_capacity(size: usize) -> UnionFind<T> {
         let parents: HashMap<T, T> = HashMap::with_capacity(size);
         let rank: HashMap<T, usize> = HashMap::with_capacity(size);
-        // for 
+        // for
         UnionFind {
             _size: size,
             parents,
-            rank
+            rank,
         }
     }
 
@@ -49,9 +57,10 @@ impl<T> UnionFind<T>
 }
 
 impl<T> UnionFindTrait<T> for UnionFind<T>
-    where
-    T: Copy + Eq + Hash + Clone
+where
+    T: Copy + Eq + Hash + Clone,
 {
+    #[allow(clippy::map_entry)]
     fn find(&mut self, node: T) -> T {
         if !self.parents.contains_key(&node) {
             self.parents.insert(node, node);
@@ -65,13 +74,16 @@ impl<T> UnionFindTrait<T> for UnionFind<T>
         *self.parents.get(&node).unwrap()
     }
 
-    fn union(&mut self, x: T, y: T){
+    fn union(&mut self, x: T, y: T) {
         let x_root = self.find(x);
         let y_root = self.find(y);
-        
+
+        #[allow(clippy::map_entry)]
         if !self.rank.contains_key(&x_root) {
             self.rank.insert(x_root, 0);
         }
+
+        #[allow(clippy::map_entry)]
         if !self.rank.contains_key(&y_root) {
             self.rank.insert(y_root, 0);
         }
@@ -83,8 +95,7 @@ impl<T> UnionFindTrait<T> for UnionFind<T>
 
         if x_root_rank > y_root_rank {
             self.parents.insert(y_root, x_root);
-        }
-        else {
+        } else {
             self.parents.insert(x_root, y_root);
             if x_root_rank == y_root_rank {
                 self.rank.insert(y_root, y_root_rank + 1);
@@ -92,14 +103,15 @@ impl<T> UnionFindTrait<T> for UnionFind<T>
         }
     }
 
-    fn into_subsets(&mut self) -> Vec<HashSet<T>> {
-
+    fn subsets(&mut self) -> Vec<HashSet<T>> {
         let mut result: HashMap<T, HashSet<T>> = HashMap::with_capacity(self.size());
 
         let rank_cp = self.rank.clone();
 
         for (&node, _) in rank_cp.iter() {
             let root = self.find(node);
+
+            #[allow(clippy::map_entry)]
             if !result.contains_key(&root) {
                 let mut hset = HashSet::new();
                 hset.insert(node);
@@ -114,34 +126,29 @@ impl<T> UnionFindTrait<T> for UnionFind<T>
     }
 }
 
-
 impl<T> IntoIterator for UnionFind<T>
 where
-    T: Copy + Eq + Hash + Clone
+    T: Copy + Eq + Hash + Clone,
 {
     type Item = HashSet<T>;
     type IntoIter = std::vec::IntoIter<Self::Item>;
 
     fn into_iter(mut self) -> Self::IntoIter {
-        self.into_subsets().into_iter()
+        self.subsets().into_iter()
     }
 }
 
-
 impl<T> fmt::Display for UnionFind<T>
 where
-    T: Clone + Eq + Hash + Copy + fmt::Debug
+    T: Clone + Eq + Hash + Copy + fmt::Debug,
 {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-
         let s = format!(
             "<UnionFind size={}, non_trivial_subsets={:?}>",
             self.size(),
-            &self.clone().into_subsets()
+            &self.clone().subsets()
         );
 
         write!(f, "{}", s)
     }
 }
-
-
